Module flexible_gpu_api

Module flexible_gpu_api 

Enums

CreateFlexibleGpuError
struct for typed errors of method create_flexible_gpu
DeleteFlexibleGpuError
struct for typed errors of method delete_flexible_gpu
LinkFlexibleGpuError
struct for typed errors of method link_flexible_gpu
ReadFlexibleGpuCatalogError
struct for typed errors of method read_flexible_gpu_catalog
ReadFlexibleGpusError
struct for typed errors of method read_flexible_gpus
UnlinkFlexibleGpuError
struct for typed errors of method unlink_flexible_gpu
UpdateFlexibleGpuError
struct for typed errors of method update_flexible_gpu

Functions

create_flexible_gpu
Allocates a flexible GPU (fGPU) to your OUTSCALE account.
You can then attach this fGPU to a virtual machine (VM).

For more information, see About Flexible GPUs.
delete_flexible_gpu
Releases a flexible GPU (fGPU) from your OUTSCALE account.
The fGPU becomes free to be used by someone else.
link_flexible_gpu
Attaches one of your allocated flexible GPUs (fGPUs) to one of your virtual machines (VMs).
To complete the linking of the fGPU, you need to do a stop/start of the VM. A simple restart is not sufficient, as the linking of the fGPU is done when the VM goes through the stopped state. For the difference between stop/start and restart, see About VM Lifecycle.

[NOTE]
You can attach fGPUs only to VMs with the highest (1) performance flag. For more information see About Flexible GPUs and VM Types.
read_flexible_gpu_catalog
Lists all flexible GPUs available in the public catalog.
read_flexible_gpus
Lists one or more flexible GPUs (fGPUs) allocated to your OUTSCALE account.
unlink_flexible_gpu
Detaches a flexible GPU (fGPU) from a virtual machine (VM).
The fGPU is in the detaching state until the VM is stopped, after which it becomes allocated. It is then available again for attachment to a VM.
update_flexible_gpu
Modifies a flexible GPU (fGPU) behavior.