create_image

Function create_image 

pub fn create_image(
    configuration: &Configuration,
    create_image_request: Option<CreateImageRequest>,
) -> Result<CreateImageResponse, Error<CreateImageError>>
Creates an OUTSCALE machine image (OMI).
You can use this method for different use cases: * Creating from a VM: You create an OMI from one of your virtual machines (VMs).
* Copying an OMI: You copy an existing OMI. The source OMI can be one of your own OMIs, or an OMI owned by another account that has granted you permission via the UpdateImage method.
* Registering from a snapshot: You register an OMI from an existing snapshot. The source snapshot can be one of your own snapshots, or a snapshot owned by another account that has granted you permission via the UpdateSnapshot method.
* Registering from a bucket by using a manifest file: You register an OMI from the manifest file of an OMI that was exported to an OUTSCALE Object Storage (OOS) bucket. First, the owner of the source OMI must export it to the bucket by using the CreateImageExportTask method. Then, they must grant you permission to read the manifest file via a pre-signed URL. For more information, see Creating a Pre-Signed URL. [TIP]
Registering from a bucket enables you to copy an OMI across Regions. For more information, see About OMIs.