Module load_balancer_api

Module load_balancer_api 

Enums

CreateLoadBalancerError
struct for typed errors of method create_load_balancer
CreateLoadBalancerTagsError
struct for typed errors of method create_load_balancer_tags
DeleteLoadBalancerError
struct for typed errors of method delete_load_balancer
DeleteLoadBalancerTagsError
struct for typed errors of method delete_load_balancer_tags
DeregisterVmsInLoadBalancerError
struct for typed errors of method deregister_vms_in_load_balancer
LinkLoadBalancerBackendMachinesError
struct for typed errors of method link_load_balancer_backend_machines
ReadLoadBalancerTagsError
struct for typed errors of method read_load_balancer_tags
ReadLoadBalancersError
struct for typed errors of method read_load_balancers
ReadVmsHealthError
struct for typed errors of method read_vms_health
RegisterVmsInLoadBalancerError
struct for typed errors of method register_vms_in_load_balancer
UnlinkLoadBalancerBackendMachinesError
struct for typed errors of method unlink_load_balancer_backend_machines
UpdateLoadBalancerError
struct for typed errors of method update_load_balancer

Functions

create_load_balancer
Creates a load balancer.
The load balancer is created with a unique Domain Name Service (DNS) name. It receives the incoming traffic and routes it to its registered virtual machines (VMs).
By default, this action creates an Internet-facing load balancer, resolving to public IPs. To create an internal load balancer in a Net, resolving to private IPs, use the LoadBalancerType parameter.
You must specify either the Subnets or the SubregionNames parameters.

For more information, see About Load Balancers.
create_load_balancer_tags
Adds one or more tags to the specified load balancers.
If a tag with the same key already exists for the load balancer, the tag value is replaced.

For more information, see About Tags.
delete_load_balancer
Deletes a specified load balancer.
delete_load_balancer_tags
Deletes one or more tags from the specified load balancers.
deregister_vms_in_load_balancer
[WARNING]
> Deprecated: This call is deprecated and will be removed.
Deregisters a specified virtual machine (VM) from a load balancer.
link_load_balancer_backend_machines
Attaches one or more virtual machines (VMs) to a specified load balancer. You need to specify at least the BackendIps or the BackendVmIds parameter.
The VMs can be in different Subnets and different Subregions than the load balancer, as long as the VMs and load balancers are all in the public Cloud or all in the same Net. It may take a little time for a VM to be registered with the load balancer. Once the VM is registered with a load balancer, it receives traffic and requests from this load balancer and is called a backend VM.
read_load_balancer_tags
Lists the tags associated with one or more specified load balancers.
read_load_balancers
Lists one or more load balancers and their attributes.
read_vms_health
Lists the state of one or more backend virtual machines (VMs) registered with a specified load balancer.
register_vms_in_load_balancer
[WARNING]
> Deprecated: This call is deprecated and will be removed.
Registers one or more virtual machines (VMs) with a specified load balancer.
The VMs can be in different Subnets and different Subregions than the load balancer, as long as the VMs and load balancers are all in the public Cloud or all in the same Net. It may take a little time for a VM to be registered with the load balancer. Once the VM is registered with a load balancer, it receives traffic and requests from this load balancer and is called a backend VM.
unlink_load_balancer_backend_machines
Detaches one or more backend virtual machines (VMs) from a load balancer. You need to specify at least the BackendIps or the BackendVmIds parameter.
update_load_balancer
Modifies the specified attribute of a load balancer. You can specify only one attribute at a time.

You can set a new SSL certificate to an SSL or HTTPS listener of a load balancer.
This certificate replaces any certificate used on the same load balancer and port.

You can also replace the currently enabled policy for the load balancer with another one.
If the PolicyNames parameter is empty, the currently enabled policy is disabled.