pub fn delete_net_access_point(
configuration: &Configuration,
delete_net_access_point_request: Option<DeleteNetAccessPointRequest>,
) -> Result<DeleteNetAccessPointResponse, Error<DeleteNetAccessPointError>>Expand description
Deletes a specified Net access point.
This action also deletes the corresponding routes added to the route tables you specified for the Net access point.