Module net_api

Module net_api 

Enums

CreateNetError
struct for typed errors of method create_net
DeleteNetError
struct for typed errors of method delete_net
ReadNetsError
struct for typed errors of method read_nets
UpdateNetError
struct for typed errors of method update_net

Functions

create_net
Creates a Net with a specified IP range.
The IP range (network range) of your Net must be between a /28 netmask (16 IPs) and a /16 netmask (65536 IPs).

For more information, see About Nets.
delete_net
Deletes a specified Net.
Before deleting the Net, you need to delete or detach all the resources associated with the Net:

* Virtual machines (VMs)
* Net peerings
* Custom route tables
* Public IPs allocated to resources in the Net
* Network Interface Cards (NICs) created in the Subnets
* Virtual gateways, internet services and NAT services
* Load balancers
* Security groups
* Subnets
read_nets
Lists one or more Nets.
update_net
Associates a DHCP options set with a specified Net.