pub fn delete_user_policy(
configuration: &Configuration,
delete_user_policy_request: Option<DeleteUserPolicyRequest>,
) -> Result<DeleteUserPolicyResponse, Error<DeleteUserPolicyError>>Expand description
Deletes a specified inline policy from a specific user.
[IMPORTANT]
A delay of up to 15 seconds can occur when creating or deleting an inline policy.