Module server_certificate_api

Module server_certificate_api 

Enums

CreateServerCertificateError
struct for typed errors of method create_server_certificate
DeleteServerCertificateError
struct for typed errors of method delete_server_certificate
ReadServerCertificatesError
struct for typed errors of method read_server_certificates
UpdateServerCertificateError
struct for typed errors of method update_server_certificate

Functions

create_server_certificate
Creates a server certificate and its matching private key.

These elements can be used with other services (for example, to configure SSL termination on load balancers).

You can also specify the chain of intermediate certification authorities if your certificate is not directly signed by a root one. You can specify multiple intermediate certification authorities in the CertificateChain parameter. To do so, concatenate all certificates in the correct order (the first certificate must be the authority of your certificate, the second must be the authority of the first one, and so on).

The private key must be a RSA key in PKCS1 form. To check this, open the PEM file and ensure its header reads as follows: BEGIN RSA PRIVATE KEY.

[IMPORTANT]

This private key must not be protected by a password or a passphrase.

For more information, see About Server Certificates in EIM.
delete_server_certificate
Deletes a specified server certificate.
read_server_certificates
Lists your server certificates.
update_server_certificate
Modifies the name and/or the path of a specified server certificate.