pub fn create_snapshot(
configuration: &Configuration,
create_snapshot_request: Option<CreateSnapshotRequest>,
) -> Result<CreateSnapshotResponse, Error<CreateSnapshotError>>Expand description
Creates a snapshot. Snapshots are point-in-time images of a volume that you can use to back up your data or to create replicas of this volume.
You can use this method in three different ways: * Creating from a volume: You create a snapshot from one of your volumes.
* Copying a snapshot: You copy an existing snapshot. The source snapshot can be one of your own snapshots, or a snapshot owned by another OUTSCALE account that has granted you permission via the UpdateSnapshot method.
* Importing from a bucket: You import a snapshot located in an OUTSCALE Object Storage (OOS) bucket. First, the owner of the source snapshot must export it to a bucket by using the CreateSnapshotExportTask method. Then, they must grant you permission to read the snapshot via a pre-signed URL. For more information, see Creating a Pre-Signed URL. [NOTE]
In case of excessive use of the snapshot creation feature on the same volume over a short period of time, 3DS OUTSCALE reserves the right to temporarily block the feature. For more information, see About Snapshots.