Module virtual_gateway_api

Module virtual_gateway_api 

Enums

CreateVirtualGatewayError
struct for typed errors of method create_virtual_gateway
DeleteVirtualGatewayError
struct for typed errors of method delete_virtual_gateway
LinkVirtualGatewayError
struct for typed errors of method link_virtual_gateway
ReadVirtualGatewaysError
struct for typed errors of method read_virtual_gateways
UnlinkVirtualGatewayError
struct for typed errors of method unlink_virtual_gateway
UpdateRoutePropagationError
struct for typed errors of method update_route_propagation

Functions

create_virtual_gateway
Creates a virtual gateway.
A virtual gateway is the access point on the Net side of a VPN connection.

For more information, see About Virtual Gateways.
delete_virtual_gateway
Deletes a specified virtual gateway.
[IMPORTANT]
Before deleting a virtual gateway, we recommend detaching it from any associated Net, DirectLink, and DirectLink interface, and deleting the VPN connection.
link_virtual_gateway
Attaches a virtual gateway to a Net. [IMPORTANT]
This action can be done only if the virtual gateway is in the available state.
read_virtual_gateways
Lists one or more virtual gateways.
unlink_virtual_gateway
Detaches a virtual gateway from a Net.
You must wait until the virtual gateway is in the detached state before you can attach another Net to it or delete the Net it was previously attached to.
update_route_propagation
Configures the propagation of routes to a specified route table of a Net by a virtual gateway.