read_admin_password

Function read_admin_password 

pub fn read_admin_password(
    configuration: &Configuration,
    read_admin_password_request: Option<ReadAdminPasswordRequest>,
) -> Result<ReadAdminPasswordResponse, Error<ReadAdminPasswordError>>
Gets the administrator password for a Windows running virtual machine (VM).
The administrator password is encrypted using the keypair you specified when launching the VM.

[IMPORTANT]
* Only RSA keypairs can decrypt the password of a Windows VM.
* The administrator password is generated only on the first boot of the Windows VM. It is not returned after the first boot.