pub struct BsuToCreate {
pub delete_on_vm_deletion: Option<bool>,
pub iops: Option<i32>,
pub snapshot_id: Option<String>,
pub volume_size: Option<i32>,
pub volume_type: Option<String>,
}Expand description
BsuToCreate : Information about the BSU volume to create.
Fields
delete_on_vm_deletion: Option<bool>If set to true, the volume is deleted when terminating the VM. If false, the volume is not deleted when terminating the VM.
iops: Option<i32>The number of I/O operations per second (IOPS). This parameter must be specified only if you create an io1 volume. The maximum number of IOPS allowed for io1 volumes is 13000 with a maximum performance ratio of 300 IOPS per gibibyte.
snapshot_id: Option<String>The ID of the snapshot used to create the volume.
volume_size: Option<i32>The size of the volume, in gibibytes (GiB).
If you specify a snapshot ID, the volume size must be at least equal to the snapshot size.
If you specify a snapshot ID but no volume size, the volume is created with a size similar to the snapshot one.
volume_type: Option<String>The type of the volume (standard \| io1 \| gp2). If not specified in the request, a standard volume is created.
For more information about volume types, see About Volumes > Volume Types and IOPS.
Implementations
Sourceimpl BsuToCreate
impl BsuToCreate
Sourcepub fn new() -> BsuToCreate
pub fn new() -> BsuToCreate
Information about the BSU volume to create.