pub struct CreateDhcpOptionsRequest {
pub domain_name: Option<String>,
pub domain_name_servers: Option<Vec<String>>,
pub dry_run: Option<bool>,
pub log_servers: Option<Vec<String>>,
pub ntp_servers: Option<Vec<String>>,
}Fields
domain_name: Option<String>Specify a domain name (for example, MyCompany.com). You can specify only one domain name. You must specify at least one of the following parameters: DomainName, DomainNameServers, LogServers, or NtpServers.
domain_name_servers: Option<Vec<String>>The IPs of domain name servers. If no IPs are specified, the OutscaleProvidedDNS value is set by default. You must specify at least one of the following parameters: DomainName, DomainNameServers, LogServers, or NtpServers.
dry_run: Option<bool>If true, checks whether you have the required permissions to perform the action.
log_servers: Option<Vec<String>>The IPs of the log servers. You must specify at least one of the following parameters: DomainName, DomainNameServers, LogServers, or NtpServers.
ntp_servers: Option<Vec<String>>The IPs of the Network Time Protocol (NTP) servers. You must specify at least one of the following parameters: DomainName, DomainNameServers, LogServers, or NtpServers.
Implementations
Sourceimpl CreateDhcpOptionsRequest
impl CreateDhcpOptionsRequest
pub fn new() -> CreateDhcpOptionsRequest