pub struct CreatePolicyVersionRequest {
pub document: String,
pub policy_orn: String,
pub set_as_default: Option<bool>,
}Fields
document: StringThe policy document, corresponding to a JSON string that contains the policy. This policy document can contain a maximum of 5120 non-whitespace characters. For more information, see EIM Reference Information and EIM Policy Generator.
policy_orn: StringThe OUTSCALE Resource Name (ORN) of the policy. For more information, see Resource Identifiers.
set_as_default: Option<bool>If set to true, the new policy version is set as the default version and becomes the operative one.
Implementations
Sourceimpl CreatePolicyVersionRequest
impl CreatePolicyVersionRequest
pub fn new(document: String, policy_orn: String) -> CreatePolicyVersionRequest