pub struct CreateUserGroupRequest {
pub dry_run: Option<bool>,
pub path: Option<String>,
pub user_group_name: String,
}Fields
dry_run: Option<bool>If true, checks whether you have the required permissions to perform the action.
path: Option<String>The path to the group. If not specified, it is set to a slash (/).
user_group_name: StringThe name of the group.
Implementations
Sourceimpl CreateUserGroupRequest
impl CreateUserGroupRequest
pub fn new(user_group_name: String) -> CreateUserGroupRequest