pub struct DeleteLoadBalancerPolicyRequest {
pub dry_run: Option<bool>,
pub load_balancer_name: String,
pub policy_name: String,
}Fields
dry_run: Option<bool>If true, checks whether you have the required permissions to perform the action.
load_balancer_name: StringThe name of the load balancer for which you want to delete a policy.
policy_name: StringThe name of the policy you want to delete.
Implementations
Sourceimpl DeleteLoadBalancerPolicyRequest
impl DeleteLoadBalancerPolicyRequest
pub fn new( load_balancer_name: String, policy_name: String, ) -> DeleteLoadBalancerPolicyRequest