pub struct NetAccessPoint {
pub net_access_point_id: Option<String>,
pub net_id: Option<String>,
pub route_table_ids: Option<Vec<String>>,
pub service_name: Option<String>,
pub state: Option<String>,
pub tags: Option<Vec<ResourceTag>>,
}Expand description
NetAccessPoint : Information about the Net access point.
Fields
net_access_point_id: Option<String>The ID of the Net access point.
net_id: Option<String>The ID of the Net with which the Net access point is associated.
route_table_ids: Option<Vec<String>>The ID of the route tables associated with the Net access point.
service_name: Option<String>The name of the service with which the Net access point is associated.
state: Option<String>The state of the Net access point (pending \| available \| deleting \| deleted).
One or more tags associated with the Net access point.
Implementations
Sourceimpl NetAccessPoint
impl NetAccessPoint
Sourcepub fn new() -> NetAccessPoint
pub fn new() -> NetAccessPoint
Information about the Net access point.