pub struct ReadNetsRequest {
pub dry_run: Option<bool>,
pub filters: Option<Box<FiltersNet>>,
pub next_page_token: Option<String>,
pub results_per_page: Option<i32>,
}Fields
dry_run: Option<bool>If true, checks whether you have the required permissions to perform the action.
filters: Option<Box<FiltersNet>>next_page_token: Option<String>The token to request the next page of results. Each token refers to a specific page.
results_per_page: Option<i32>The maximum number of logs returned in a single response (between 1 and 1000, both included).
Implementations
Sourceimpl ReadNetsRequest
impl ReadNetsRequest
pub fn new() -> ReadNetsRequest