pub struct ReadPolicyVersionsResponse {
pub has_more_items: Option<bool>,
pub max_results_limit: Option<i32>,
pub policy_versions: Option<Vec<PolicyVersion>>,
pub response_context: Option<Box<ResponseContext>>,
}Fields
has_more_items: Option<bool>If true, there are more items to return using the FirstItem parameter in a new request.
max_results_limit: Option<i32>Indicates maximum results defined for the operation.
policy_versions: Option<Vec<PolicyVersion>>A list of all the versions of the policy.
response_context: Option<Box<ResponseContext>>Implementations
Sourceimpl ReadPolicyVersionsResponse
impl ReadPolicyVersionsResponse
pub fn new() -> ReadPolicyVersionsResponse