pub struct UpdateNetRequest {
pub dhcp_options_set_id: String,
pub dry_run: Option<bool>,
pub net_id: String,
}Fields
dhcp_options_set_id: StringThe ID of the DHCP options set (or default if you want to associate the default one).
dry_run: Option<bool>If true, checks whether you have the required permissions to perform the action.
net_id: StringThe ID of the Net.
Implementations
Sourceimpl UpdateNetRequest
impl UpdateNetRequest
pub fn new(dhcp_options_set_id: String, net_id: String) -> UpdateNetRequest