pub struct UpdateRouteTableLinkRequest {
pub dry_run: Option<bool>,
pub link_route_table_id: String,
pub route_table_id: String,
}Fields
dry_run: Option<bool>If true, checks whether you have the required permissions to perform the action.
link_route_table_id: StringThe ID of the current route table link.
route_table_id: StringThe ID of the new route table to associate with the Subnet.
Implementations
Sourceimpl UpdateRouteTableLinkRequest
impl UpdateRouteTableLinkRequest
pub fn new( link_route_table_id: String, route_table_id: String, ) -> UpdateRouteTableLinkRequest