pub struct VolumeUpdateTask {
pub comment: Option<String>,
pub completion_date: Option<String>,
pub progress: Option<i32>,
pub start_date: Option<String>,
pub state: Option<String>,
pub tags: Option<Vec<ResourceTag>>,
pub task_id: Option<String>,
pub volume_id: Option<String>,
pub volume_update: Option<Box<VolumeUpdate>>,
}Expand description
VolumeUpdateTask : Information about the volume update task.
Fields
comment: Option<String>If the update volume task fails, an error message appears.
completion_date: Option<String>The date at which the volume update task was marked as completed.
progress: Option<i32>The progress of the volume update task, as a percentage.
start_date: Option<String>The creation date of the volume update task.
state: Option<String>The state of the volume (pending \| active \| completed \| failed \| canceled).
One or more tags associated with the volume update task.
task_id: Option<String>The ID of the volume update task in progress. Otherwise, it is not returned.
volume_id: Option<String>The ID of the updated volume.
volume_update: Option<Box<VolumeUpdate>>Implementations
Sourceimpl VolumeUpdateTask
impl VolumeUpdateTask
Sourcepub fn new() -> VolumeUpdateTask
pub fn new() -> VolumeUpdateTask
Information about the volume update task.