pub fn update_api_access_rule(
configuration: &Configuration,
update_api_access_rule_request: Option<UpdateApiAccessRuleRequest>,
) -> Result<UpdateApiAccessRuleResponse, Error<UpdateApiAccessRuleError>>Expand description
Modifies a specified API access rule.
[WARNING]
- The new rule you specify fully replaces the old rule. Therefore, for a parameter that is not specified, any previously set value is deleted.
- If, as result of your modification, you no longer have access to the APIs, you will need to contact the Support team to regain access. For more information, see Technical Support.