Enums
- Create
Flexible GpuError - struct for typed errors of method
create_flexible_gpu - Delete
Flexible GpuError - struct for typed errors of method
delete_flexible_gpu - Link
Flexible GpuError - struct for typed errors of method
link_flexible_gpu - Read
Flexible GpuCatalog Error - struct for typed errors of method
read_flexible_gpu_catalog - Read
Flexible Gpus Error - struct for typed errors of method
read_flexible_gpus - Unlink
Flexible GpuError - struct for typed errors of method
unlink_flexible_gpu - Update
Flexible GpuError - struct for typed errors of method
update_flexible_gpu
Functions
- create_
flexible_ gpu - Allocates a flexible GPU (fGPU) to your OUTSCALE account.
You can then attach this fGPU to a virtual machine (VM).
For more information, see About Flexible GPUs. - delete_
flexible_ gpu - Releases a flexible GPU (fGPU) from your OUTSCALE account.
The fGPU becomes free to be used by someone else. - link_
flexible_ gpu - Attaches one of your allocated flexible GPUs (fGPUs) to one of your virtual machines (VMs).
To complete the linking of the fGPU, you need to do a stop/start of the VM. A simple restart is not sufficient, as the linking of the fGPU is done when the VM goes through thestoppedstate. For the difference between stop/start and restart, see About VM Lifecycle.
[NOTE]
You can attach fGPUs only to VMs with thehighest(1) performance flag. For more information see About Flexible GPUs and VM Types. - read_
flexible_ gpu_ catalog - Lists all flexible GPUs available in the public catalog.
- read_
flexible_ gpus - Lists one or more flexible GPUs (fGPUs) allocated to your OUTSCALE account.
- unlink_
flexible_ gpu - Detaches a flexible GPU (fGPU) from a virtual machine (VM).
The fGPU is in thedetachingstate until the VM is stopped, after which it becomesallocated. It is then available again for attachment to a VM. - update_
flexible_ gpu - Modifies a flexible GPU (fGPU) behavior.