Creates a Net with a specified IP range. The IP range (network range) of your Net must be between a /28 netmask (16 IPs) and a /16 netmask (65536 IPs).
Deletes a specified Net. Before deleting the Net, you need to delete or detach all the resources associated with the Net:
* Virtual machines (VMs) * Net peerings * Custom route tables * Public IPs allocated to resources in the Net * Network Interface Cards (NICs) created in the Subnets * Virtual gateways, internet services and NAT services * Load balancers * Security groups * Subnets