Skip to main content Module subnet_api Copy item path Source CreateSubnetError struct for typed errors of method create_subnet DeleteSubnetError struct for typed errors of method delete_subnet ReadSubnetsError struct for typed errors of method read_subnets UpdateSubnetError struct for typed errors of method update_subnet create_subnet Creates a Subnet in an existing Net. To create a Subnet in a Net, you have to provide the ID of the Net and the IP range for the Subnet (its network range). Once the Subnet is created, you cannot modify its IP range. For more information, see About Nets . delete_subnet Deletes a specified Subnet. Before deleting the Subnet, you need to delete all resources associated with the Subnet: * Virtual machines (VMs) * Network Interface Cards (NICs) * NAT services * Load balancers read_subnets Lists one or more of your Subnets. If you do not specify any Subnet ID, this action describes all of your Subnets. update_subnet Modifies the specified attribute of a Subnet.