Enums
- Create
Virtual Gateway Error - struct for typed errors of method
create_virtual_gateway - Delete
Virtual Gateway Error - struct for typed errors of method
delete_virtual_gateway - Link
Virtual Gateway Error - struct for typed errors of method
link_virtual_gateway - Read
Virtual Gateways Error - struct for typed errors of method
read_virtual_gateways - Unlink
Virtual Gateway Error - struct for typed errors of method
unlink_virtual_gateway - Update
Route Propagation Error - struct for typed errors of method
update_route_propagation
Functions
- create_
virtual_ gateway - Creates a virtual gateway.
A virtual gateway is the access point on the Net side of a VPN connection.
For more information, see About Virtual Gateways. - delete_
virtual_ gateway - Deletes a specified virtual gateway.
[IMPORTANT]
Before deleting a virtual gateway, we recommend detaching it from any associated Net, DirectLink, and DirectLink interface, and deleting the VPN connection. - link_
virtual_ gateway - Attaches a virtual gateway to a Net. [IMPORTANT]
This action can be done only if the virtual gateway is in theavailablestate. - read_
virtual_ gateways - Lists one or more virtual gateways.
- unlink_
virtual_ gateway - Detaches a virtual gateway from a Net.
You must wait until the virtual gateway is in the detached state before you can attach another Net to it or delete the Net it was previously attached to. - update_
route_ propagation - Configures the propagation of routes to a specified route table of a Net by a virtual gateway.