pub fn update_vm_template(
configuration: &Configuration,
update_vm_template_request: Option<UpdateVmTemplateRequest>,
) -> Result<UpdateVmTemplateResponse, Error<UpdateVmTemplateError>>Expand description
[WARNING]
> This feature is currently under development and may not function properly.
Modifies the specified attributes of a template of virtual machines (VMs).