pub struct Vm {Show 37 fields
pub actions_on_next_boot: Option<Box<ActionsOnNextBoot>>,
pub architecture: Option<String>,
pub block_device_mappings: Option<Vec<BlockDeviceMappingCreated>>,
pub boot_mode: Option<BootMode>,
pub bsu_optimized: Option<bool>,
pub client_token: Option<String>,
pub creation_date: Option<String>,
pub deletion_protection: Option<bool>,
pub hypervisor: Option<String>,
pub image_id: Option<String>,
pub is_source_dest_checked: Option<bool>,
pub keypair_name: Option<String>,
pub launch_number: Option<i32>,
pub nested_virtualization: Option<bool>,
pub net_id: Option<String>,
pub nics: Option<Vec<NicLight>>,
pub os_family: Option<String>,
pub performance: Option<String>,
pub placement: Option<Box<Placement>>,
pub private_dns_name: Option<String>,
pub private_ip: Option<String>,
pub product_codes: Option<Vec<String>>,
pub public_dns_name: Option<String>,
pub public_ip: Option<String>,
pub reservation_id: Option<String>,
pub root_device_name: Option<String>,
pub root_device_type: Option<String>,
pub security_groups: Option<Vec<SecurityGroupLight>>,
pub state: Option<String>,
pub state_reason: Option<String>,
pub subnet_id: Option<String>,
pub tags: Option<Vec<ResourceTag>>,
pub tpm_enabled: Option<bool>,
pub user_data: Option<String>,
pub vm_id: Option<String>,
pub vm_initiated_shutdown_behavior: Option<String>,
pub vm_type: Option<String>,
}Expand description
Vm : Information about the VM.
Fields
actions_on_next_boot: Option<Box<ActionsOnNextBoot>>architecture: Option<String>The architecture of the VM (i386 \| x86_64).
block_device_mappings: Option<Vec<BlockDeviceMappingCreated>>The block device mapping of the VM.
boot_mode: Option<BootMode>bsu_optimized: Option<bool>This parameter is not available. It is present in our API for the sake of historical compatibility with AWS.
client_token: Option<String>The idempotency token provided when launching the VM.
creation_date: Option<String>The date and time (UTC) at which the VM was created.
deletion_protection: Option<bool>If true, you cannot delete the VM unless you change this parameter back to false.
hypervisor: Option<String>The hypervisor type of the VMs (ovm \| xen).
image_id: Option<String>The ID of the OMI used to create the VM.
is_source_dest_checked: Option<bool>(Net only) If true, the source/destination check is enabled. If false, it is disabled.
keypair_name: Option<String>The name of the keypair used when launching the VM.
launch_number: Option<i32>The number for the VM when launching a group of several VMs (for example, 0, 1, 2, and so on).
nested_virtualization: Option<bool>If true, nested virtualization is enabled. If false, it is disabled.
net_id: Option<String>The ID of the Net in which the VM is running.
nics: Option<Vec<NicLight>>(Net only) The network interface cards (NICs) the VMs are attached to.
os_family: Option<String>Indicates the operating system (OS) of the VM.
performance: Option<String>The performance of the VM.
placement: Option<Box<Placement>>private_dns_name: Option<String>The name of the private DNS.
private_ip: Option<String>The primary private IP of the VM.
product_codes: Option<Vec<String>>The product codes associated with the OMI used to create the VM.
public_dns_name: Option<String>The name of the public DNS.
public_ip: Option<String>The public IP of the VM.
reservation_id: Option<String>The reservation ID of the VM.
root_device_name: Option<String>The name of the root device for the VM (for example, /dev/sda1).
root_device_type: Option<String>The type of root device used by the VM (always bsu).
security_groups: Option<Vec<SecurityGroupLight>>One or more security groups associated with the VM.
state: Option<String>The state of the VM (pending \| running \| stopping \| stopped \| shutting-down \| terminated \| quarantine).
state_reason: Option<String>The reason explaining the current state of the VM.
subnet_id: Option<String>The ID of the Subnet for the VM.
One or more tags associated with the VM.
tpm_enabled: Option<bool>If true, a virtual Trusted Platform Module (vTPM) is enabled on the VM. If false, it is not.
user_data: Option<String>The Base64-encoded MIME user data.
vm_id: Option<String>The ID of the VM.
vm_initiated_shutdown_behavior: Option<String>The VM behavior when you stop it. If set to stop, the VM stops. If set to restart, the VM stops then automatically restarts. If set to terminate, the VM stops and is deleted.
vm_type: Option<String>The type of VM. For more information, see VM Types.
Implementations